%thermistor
% Function which models a thermistor component and plots a resistance vs
% temperature and current vs voltage curve.
%
% Last updated by Andy French 21/10/1205

function thermistor

%Define graph fontsize
fsize = 18;

% Define two (R,T) points and fit an exponential decay curve to R vs T
% Temperature is in degrees Celsius and resistance is in kohms. (1000
% ohms). Curve is R = R1* exp( -kT );
R1 = 95;
T1 = -20;
R2 = 5;
T2 = 40;
k = log( R2/R1)/(T1-T2);
R1 = R1/exp(-k*T1);

%Define temperature range and plot curve
T = linspace( -20,100,1000 );
R = R1*exp( -k*T );
figure('color',[1 1 1],'name','thermistor');
plot(T,R);
xlim([min(T),max(T)]);
grid on;
set(gca,'fontsize',fsize);
xlabel('Temperature /^oC', 'fontsize', fsize );
ylabel('Resistance /k\Omega', 'fontsize', fsize );
title('Thermistor R vs T curve','fontsize',fsize );
print( gcf, 'thermistor R vs T.png','-dpng','-r300' );
cla;

%Define input voltages and plot I vs temperature curve. 
%Use Ohm's Law V = IR to find current I in mA
V = [1,2,3,4,5];
for n=1:length(V)
    I(:,n) = V(n)./R(:).';
    legend_str{n} = ['V = ',num2str(V(n)),' volts'];
end
plot( repmat(T.',[1,length(V)]), I );
legend(legend_str,'location','best')
xlim([min(T),max(T)]);
grid on;
set(gca,'fontsize',fsize);
xlabel('Temperature /^oC', 'fontsize', fsize );
ylabel('Current I/mA', 'fontsize', fsize );
title('Thermistor I vs T curve','fontsize',fsize );
print( gcf, 'thermistor I vs T.png','-dpng','-r300' );
close(gcf);    

%Now place thermistor in a potential divider circuit with a fixed resistor
%R1 / kohms
R1 = [1,3,5,10,20,50,70,100,150,200];
V_by_V0 = ones( length(R),length(R1) );
for n=1:length(R1)
    V_by_V0(:,n) = R(:).'./(R(:).' + R1(n));
    legend_str{n} = ['R_1 = ',num2str(R1(n)),' k\Omega'];
end
plot( repmat(T.',[1,length(R1)]), V_by_V0 );
legend(legend_str,'location','eastoutside')
xlim([min(T),max(T)]);
ylim([0,1])
grid on;
set(gca,'fontsize',fsize);
xlabel('Temperature /^oC', 'fontsize', fsize );
ylabel('V / V_0', 'fontsize', fsize );
title('Thermistor potential divider V/V_0 vs T curve','fontsize',fsize );
print( gcf, 'thermistor pot div V vs T.png','-dpng','-r300' );
close(gcf);  

%Now assume thermistor is in series with a large fixed resistor (units of
%kohms)
R0 = 1000;
R1 = [100,200,500,1000,2000,3000,5000];
V_by_V0 = ones( length(R),length(R1) );
for n=1:length(R1)
    V_by_V0(:,n) = ( R(:).' + R0 )./(R(:).' + R0 + R1(n));
    legend_str{n} = ['R_1 = ',num2str(R1(n)),' k\Omega'];
end
plot( repmat(T.',[1,length(R1)]), V_by_V0 );
legend(legend_str,'location','eastoutside')
xlim([min(T),max(T)]);
ylim([0,1]);
grid on;
set(gca,'fontsize',fsize);
xlabel('Temperature /^oC', 'fontsize', fsize );
ylabel('V / V_0', 'fontsize', fsize );
title('Thermistor potential divider V/V_0 vs T curve','fontsize',fsize );
print( gcf, 'thermistor pot div V vs T with large R0.png','-dpng','-r300' );
close(gcf);  

%Now put thermistor plus large fixed resistor in a Wheatstone Bridge
%circuit
R0 = [1000,2000,3000,5000];
V_by_V0 = ones( length(R),length(R0) );
for n=1:length(R0)
    x = R/R0(n);
    V_by_V0(:,n) = (1+x(:).')./(2+x(:).') - 0.5;
    legend_str{n} = ['R_0 = ',num2str(R0(n)),' k\Omega'];
end
plot( repmat(T.',[1,length(R0)]), V_by_V0 );
legend(legend_str,'location','eastoutside')
xlim([min(T),max(T)]);
%ylim([0,0.5]);
grid on;
set(gca,'fontsize',fsize);
xlabel('Temperature /^oC', 'fontsize', fsize );
ylabel('V / V_0', 'fontsize', fsize );
title('Thermistor wheatstone bridge V/V_0 vs T curve','fontsize',fsize );
print( gcf, 'thermistor bridge V vs T with large R0.png','-dpng','-r300' );
close(gcf);  


%End of code